@@ -8,7 +8,7 @@ import textwrap
 from typing import Any, Dict, List, Optional, Sequence, Tuple, TypeVar, Union
 
 import git_machete.options
-from git_machete import __version__, utils
+from git_machete import __version__, git_config_keys, utils
 from git_machete.client import MacheteClient
 from git_machete.exceptions import ExitCode, MacheteException, StopInteraction
 from git_machete.generated_docs import long_docs, short_docs
@@ -468,7 +468,7 @@ def update_cli_options_using_config_keys(
         cli_opts: git_machete.options.CommandLineOptions,
         git: GitContext
 ) -> None:
-    machete_traverse_push_config_key = git.get_boolean_config_attr_or_none(key='machete.traverse.push')
+    machete_traverse_push_config_key = git.get_boolean_config_attr_or_none(key=git_config_keys.TRAVERSE_PUSH)
     if machete_traverse_push_config_key is not None:
         if machete_traverse_push_config_key:
             cli_opts.opt_push_tracked, cli_opts.opt_push_untracked = True, True
@@ -630,7 +630,7 @@ def launch(orig_args: List[str]) -> None:
                     machete_client.set_fork_point_override(branch, upstream)
                 else:
                     raise MacheteException(
-                        f"Branch {branch} does not have upstream (parent) branch")
+                        f"Branch {bold(branch)} does not have upstream (parent) branch")
             elif cli_opts.opt_unset_override:
                 machete_client.unset_fork_point_override(branch)
             else:
